@@ -14,11 +14,11 @@ Text::Amuse - Perl module to generate HTML and LaTeX documents from Emacs Muse m
 
 =head1 VERSION
 
-Version 0.40
+Version 0.41
 
 =cut
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 
 =head1 SYNOPSIS
@@ -419,7 +419,8 @@ sub hyphenation {
 
 The updated manual can be found at
 L<http://www.amusewiki.org/library/manual> and is also present between
-the test files (C<t/testfiles/manual.muse>).
+the test files (C<t/testfiles/manual.muse>), even if is just seldom
+updated.
 
 =head3 Inline markup
 
@@ -432,8 +433,6 @@ Added tag <sup> and <sub> for superscript and subscript.
 
 =head3 Block markup
 
-Description lists have been dropped. (Lists work as usual).
-
 The only tables supported are the native one (with ||| as separator).
 
 =head3 Others
